## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 6;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond_without  tests
# For testing/development purposes, it could make sense to do a mock build with
# --with network_tests --enable-network.
%bcond_with     network_tests

Name:           python-msal
Version:        1.23.0
Release:        %autorelease
Summary:        Microsoft Authentication Library (MSAL) for Python

# SPDX
License:        MIT
URL:            https://github.com/AzureAD/microsoft-authentication-library-for-python
%global srcversion %(echo '%{version}' | tr -d '~')
Source0:        %{url}/archive/%{srcversion}/microsoft-authentication-library-for-python-%{srcversion}.tar.gz

BuildArch:      noarch

%global _description %{expand:
The Microsoft Authentication Library for Python enables applications to
integrate with the Microsoft identity platform. It allows you to sign in users
or apps with Microsoft identities (Azure AD, Microsoft Accounts and Azure AD
B2C accounts) and obtain tokens to call Microsoft APIs such as Microsoft Graph
or your own APIs registered with the Microsoft identity platform. It is built
using industry standard OAuth2 and OpenID Connect protocols.}

%description %{_description}


%package -n python%{python3_pkgversion}-msal
Summary:        %{summary}

BuildRequires:  python%{python3_pkgversion}-devel

# We omit upper version bounds in the following, because rpm in EPEL7 does not
# support rich dependencies and because too-new dependencies are not at all a
# likely problem in EPEL7.

# setup.cfg: install_requires
BuildRequires:  python%{python3_pkgversion}-requests >= 2
Requires:       python%{python3_pkgversion}-requests >= 2
BuildRequires:  python%{python3_pkgversion}-jwt >= 1
Requires:       python%{python3_pkgversion}-jwt >= 1
# The above dependency is PyJWT[crypto], but EPEL8 does not have extras
# metapackages; the extra depends on cryptography >= 1.4, which tightents this
# package’s own dependency on cryptography>=0.6,<44. See:
# https://github.com/jpadilla/pyjwt/blob/285afade1d14eb810615c5bc751ea2c6a7a3314a/setup.py#L74.
BuildRequires:  python%{python3_pkgversion}-cryptography >= 1.4
Requires:       python%{python3_pkgversion}-cryptography >= 1.4

# setup.cfg: options.extras_require.broker
# Not packaged for EPEL7:
# BuildRequires:  python%%{python3_pkgversion}-pymsalruntime >= 0.13.2
# Requires:       python%%{python3_pkgversion}-pymsalruntime >= 0.13.2

%if %{with tests}
# Not strictly required, but a convenient test runner
BuildRequires:  python%{python3_pkgversion}-pytest
%endif

%description -n python%{python3_pkgversion}-msal %{_description}


%prep
%autosetup -n microsoft-authentication-library-for-python-%{srcversion} -p1


%build
%py3_build


%install
%py3_install


%if %{with tests}
%check
%if %{without network_tests}
# All of the following require network access:
k="${k-}${k+ and }not TestClientApplicationAcquireTokenSilentErrorBehaviors"
k="${k-}${k+ and }not TestClientApplicationAcquireTokenSilentFociBehaviors"
k="${k-}${k+ and }not TestClientApplicationForAuthorityMigration"
k="${k-}${k+ and }not TestTelemetryMaintainingOfflineState"
k="${k-}${k+ and }not TestClientApplicationWillGroupAccounts"
k="${k-}${k+ and }not TestClientCredentialGrant"
k="${k-}${k+ and }not TestScopeDecoration"
k="${k-}${k+ and }not (TestAuthority and test_unknown_host_wont_pass_instance_discovery)"
k="${k-}${k+ and }not (TestAuthority and test_wellknown_host_and_tenant)"
k="${k-}${k+ and }not (TestAuthority and test_wellknown_host_and_tenant_using_new_authority_builder)"
k="${k-}${k+ and }not TestAuthorityInternalHelperUserRealmDiscovery"
k="${k-}${k+ and }not TestCcsRoutingInfoTestCase"
k="${k-}${k+ and }not TestApplicationForRefreshInBehaviors"
k="${k-}${k+ and }not TestTelemetryOnClientApplication"
k="${k-}${k+ and }not TestTelemetryOnPublicClientApplication"
k="${k-}${k+ and }not TestTelemetryOnConfidentialClientApplication"
# Without network access, this even errors during test collection!
ignore="${ignore-} --ignore=tests/test_e2e.py"
%else
# This test requires browser interaction.
k="${k-}${k+ and }not (SshCertTestCase and test_ssh_cert_for_user_should_work_with_any_account)"
%endif

PYTHONPATH='%{buildroot}%{python3_sitelib}' PYTHONDONTWRITEBYTECODE=1 \
    %{python3} -m pytest tests ${ignore-} -k "${k-}" -v
%endif


%files -n python%{python3_pkgversion}-msal
%license LICENSE
%doc README.md

%{python3_sitelib}/msal/
%{python3_sitelib}/msal-%{version}-py%{python3_version}.egg-info/


%changelog
* Tue Aug 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.23.0-6
- Backport to EPEL7 (close RHBZ#2229737)
- We do not build a Python 2 version because there is no python2-jwt.

* Tue Aug 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.23.0-5
- Reflow the description text

* Tue Aug 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.23.0-4
- Confirm the License is SPDX MIT

* Tue Aug 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.23.0-3
- Simplify macro usage: drop srcname and “forge” macros

* Tue Aug 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.23.0-2
- Do run tests that can be run offline

* Wed Aug 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.23.0-1
- Update to 1.23.0

* Wed Aug 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.22.0-2
- Backport to EPEL8 (close RHBZ#2229737)

* Thu Jul 06 2023 Major Hayden <major@redhat.com> - 1.22.0-1
- Update to 1.22.0 rhbz#2219715

* Wed Jun 14 2023 Python Maint <python-maint@redhat.com> - 1.20.0-3
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.20.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Nov 01 2022 Major Hayden <major@redhat.com> - 1.20.0-1
- Update to 1.20.0

* Fri Oct 14 2022 Major Hayden <major@redhat.com> - 1.20.0~b1-1
- Update to 1.20.0b1

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.18.0~b1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> - 1.18.0~b1-2
- Rebuilt for Python 3.11

* Tue May 24 2022 Major Hayden <major@mhtx.net> - 1.18.0~b1-1
- Update to 1.18.0~b1

* Fri Feb 11 2022 Major Hayden <major@mhtx.net> - 1.17.0-1
- Update to 1.17.0

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.16.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Dec 15 2021 Major Hayden <major@mhtx.net> - 1.16.0-1
- Update to 1.16.0

* Fri Nov 12 2021 Major Hayden <major@mhtx.net> - 1.15.0-2
- Remove docs

* Mon Oct 04 2021 Major Hayden <major@mhtx.net> - 1.15.0-1
- 🚀 Update to 1.15.0

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.13.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jul 21 2021 Major Hayden <major@mhtx.net> - 1.13.0-1
- Update to 1.13.0

* Tue Jul 06 2021 Major Hayden <major@mhtx.net> - 1.12.0-4
- Fix lato font requirement

* Thu Jun 10 2021 Stephen Gallagher <sgallagh@redhat.com> - 1.12.0-3
- Fix conditional to work when %%fedora is not defined

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1.12.0-2
- Rebuilt for Python 3.10

* Fri Jun 04 2021 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.12.0-1
- Update to 1.12.0

* Sun Mar 21 2021 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.10.0-2
- Fix doc. build + disable online unit tests

* Sun Mar 21 2021 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.10.0-1
- Update to 1.10.0

* Mon Feb 15 2021 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 08 2021 Tom Stellard <tstellar@redhat.com> - 1.4.3-3
- Add BuildRequires: make

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 25 2020 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-1
- Update to 1.4 3

* Fri Jul 24 2020 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.2-1
- Update to 1.4.2

* Sat Jun 27 2020 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.1-1
- Update to 1.4.1

* Sun May 31 2020 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.3.0-2
- Rebuild for Python 3.9

* Fri May 29 2020 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.3.0-1
- First import
